@@ -3,7 +3,7 @@ parameter estimation and uncertainty analysis with the open-source suite PEST (D
 and 2010b, and Doherty and other, 2010).
 """
 
-from .swatmf_utils import *
+from .utils import *
 from .swatmf_viz import *
 from .swatmf_pst_utils import *
 from .swatmf_pst_par import *
